@@ -49,7 +49,7 @@ extern "C"
 #endif				/* !tds_sysdep_int32_type */
 
 #ifndef tds_sysdep_int64_type
-#define tds_sysdep_int64_type long long	/* 64-bit int */
+#define tds_sysdep_int64_type long	/* 64-bit int */
 #endif				/* !tds_sysdep_int64_type */
 
 #ifndef tds_sysdep_real32_type
